@@ -22,6 +22,9 @@ func expectPrintedCommon(t *testing.T, name string, contents string, expected st
 		msgs := log.Done()
 		text := ""
 		for _, msg := range msgs {
+			if msg.Kind != logger.Error {
+				continue
+			}
 			text += msg.String(logger.OutputOptions{}, logger.TerminalInfo{})
 		}
 		test.AssertEqualWithDiff(t, text, "")
@@ -538,7 +541,7 @@ func TestFor(t *testing.T) {
 	expectPrinted(t, "for (x(a in b);;);", "for (x(a in b); ; ) ;\n")
 	expectPrinted(t, "for (x[a in b];;);", "for (x[a in b]; ; ) ;\n")
 	expectPrinted(t, "for (x?.[a in b];;);", "for (x?.[a in b]; ; ) ;\n")
-	expectPrinted(t, "for ((x => a in b);;);", "for ((x) => (a in b); ; ) ;\n")
+	expectPrinted(t, "for ((x => a in b);;);", "for (((x) => a in b); ; ) ;\n")
 
 	// Make sure for-of loops with commas are wrapped in parentheses
 	expectPrinted(t, "for (let a in b, c);", "for (let a in b, c) ;\n")
@@ -571,7 +574,7 @@ func TestCommentsAndParentheses(t *testing.T) {
 	expectPrinted(t, "(/* foo */ function f() { foo(f) }());", "/* foo */\n(function f() {\n  foo(f);\n})();\n")
 	expectPrinted(t, "(/* foo */ class x { static y() { foo(x) } }.y());", "/* foo */\n(class x {\n  static y() {\n    foo(x);\n  }\n}).y();\n")
 	expectPrinted(t, "(/* @__PURE__ */ (() => foo())());", "/* @__PURE__ */ (() => foo())();\n")
-	expectPrinted(t, "export default (/* foo */ function f() {});", "export default (\n  /* foo */\n  function f() {\n  }\n);\n")
+	expectPrinted(t, "export default (/* foo */ function f() {});", "export default (\n  /* foo */\n  (function f() {\n  })\n);\n")
 	expectPrinted(t, "export default (/* foo */ class x {});", "export default (\n  /* foo */\n  class x {\n  }\n);\n")
 	expectPrinted(t, "x = () => (/* foo */ {});", "x = () => (\n  /* foo */\n  {}\n);\n")
 	expectPrinted(t, "for ((/* foo */ let).x of y) ;", "for (\n  /* foo */\n  (let).x of y\n) ;\n")
@@ -592,13 +595,13 @@ func TestPureComment(t *testing.T) {
 
 	expectPrinted(t,
 		"new (function() {})",
-		"new function() {\n}();\n")
+		"new (function() {\n})();\n")
 	expectPrinted(t,
 		"new (function() {})()",
-		"new function() {\n}();\n")
+		"new (function() {\n})();\n")
 	expectPrinted(t,
 		"/*@__PURE__*/new (function() {})()",
-		"/* @__PURE__ */ new function() {\n}();\n")
+		"/* @__PURE__ */ new (function() {\n})();\n")
 
 	expectPrinted(t,
 		"export default (function() { foo() })",
@@ -739,6 +742,12 @@ func TestImport(t *testing.T) {
 	expectPrinted(t, "import(/* webpackFoo: 1 */ 'path', { type: 'module' } /* webpackBar:2 */ );", "import(\n  /* webpackFoo: 1 */\n  \"path\",\n  { type: \"module\" }\n  /* webpackBar:2 */\n);\n")
 	expectPrinted(t, "import(new URL('path', /* webpackFoo: these can go anywhere */ import.meta.url))",
 		"import(new URL(\n  \"path\",\n  /* webpackFoo: these can go anywhere */\n  import.meta.url\n));\n")
+
+	// See: https://github.com/tc39/proposal-defer-import-eval
+	expectPrintedMinify(t, "import defer * as foo from 'bar'", "import defer*as foo from\"bar\";")
+
+	// See: https://github.com/tc39/proposal-source-phase-imports
+	expectPrintedMinify(t, "import source foo from 'bar'", "import source foo from\"bar\";")
 }
 
 func TestExportDefault(t *testing.T) {
@@ -1150,3 +1159,15 @@ func TestUsing(t *testing.T) {
 	expectPrintedMinify(t, "await using x = y", "await using x=y;")
 	expectPrintedMinify(t, "await using x = y, z = _", "await using x=y,z=_;")
 }
+
+func TestMinifyBigInt(t *testing.T) {
+	expectPrintedTargetMangle(t, 2019, "x = 0b100101n", "x = /* @__PURE__ */ BigInt(37);\n")
+	expectPrintedTargetMangle(t, 2019, "x = 0B100101n", "x = /* @__PURE__ */ BigInt(37);\n")
+	expectPrintedTargetMangle(t, 2019, "x = 0o76543210n", "x = /* @__PURE__ */ BigInt(16434824);\n")
+	expectPrintedTargetMangle(t, 2019, "x = 0O76543210n", "x = /* @__PURE__ */ BigInt(16434824);\n")
+	expectPrintedTargetMangle(t, 2019, "x = 0xFEDCBA9876543210n", "x = /* @__PURE__ */ BigInt(\"0xFEDCBA9876543210\");\n")
+	expectPrintedTargetMangle(t, 2019, "x = 0XFEDCBA9876543210n", "x = /* @__PURE__ */ BigInt(\"0XFEDCBA9876543210\");\n")
+	expectPrintedTargetMangle(t, 2019, "x = 0xb0ba_cafe_f00dn", "x = /* @__PURE__ */ BigInt(0xb0bacafef00d);\n")
+	expectPrintedTargetMangle(t, 2019, "x = 0xB0BA_CAFE_F00Dn", "x = /* @__PURE__ */ BigInt(0xB0BACAFEF00D);\n")
+	expectPrintedTargetMangle(t, 2019, "x = 102030405060708090807060504030201n", "x = /* @__PURE__ */ BigInt(\"102030405060708090807060504030201\");\n")
+}
